#####################################################################################################
##Creates Figures in Main Article of When Does Information Influence Voters? The Joint Importance of Salience and Coordination
######################################################################################################
#####################################################################################################

library(foreign)

##Figure 2: Effect of Joint Coordination and Salience Treatments on Incumbnet Party Vote Share, by Incumbent Performance

## Treatment effect by category of performance

# Marginal effects calculated in 05_official_saliencecoordbyperformance.do

a2 <- matrix(NA, 2, 4)
a2[1,1] <- -0.031
a2[2, 1] <- 0.018
a2[1, 2] <- 0.03
a2[2, 2] <- 0.030
a2[1,3] <- 0.038
a2[2, 3] <- 0.025
a2[1, 4] <- 0.054
a2[2, 4] <- 0.024

xs <- c(.5, 2, 3, 4.5)
ys <- c(-.1, 0, .1, .1)
x <- c(1, 2, 3, 4)

s <- 0.2
pch <- c(19, 24)
s1 <- .04
w <- 1.5
w1 <- 1

par(mar=c(5, 6, 1, 2))

plot(xs, ys, pch="", xaxt="n", las=2, ylab="Salience + Coordination Treatment Effect", xlab="Incumbent Performance", ylim=c(-.1, .1), cex.axis=1.1, cex.lab=1.2)
	
		points(x, a2[1,] , pch=19, cex=1.5)
	for(i in 1:4) {
		
	segments(i, a2[1,i] +1.96*a2[2,i]  ,i    ,a2[1,i] -1.96*a2[2,i], lwd=1.2)

	}
	segments(-10, 0, 10, 0, lty=2)
	axis(side=1, at=c(1, 2, 3, 4),cex.axis=1.1,	labels=c("Much Worse", "Worse", "Better", "Much Better"), tick=FALSE)

######################################################################################################
#####################################################################################################

## Figure 3: Predicted Values by Treatment Condition and Incumbent Performance in High Dosage Communes
## Results from Do/predicted_values.do
##Generates file predicted_values.pdf

good <- c(.332, .312, .372)
gse <- c(.004, .012, .018)

bad <- c(.40, .41, .40)
bse <- c(.004, .026, .017)

nms <- c("Control", "Information Only", "Salience")

xs <- c(1, 2, 3)

seg <- .2

plot(xs, good, xlim=c(0.5, 3.5), las=1, ylab="Predicted Voteshare", pch=19, 
	ylim=c(.28, .45), xlab="Condition", xaxt="n")
	
	points(xs+seg, bad, pch=24)
	axis(1, at=xs, labels=nms)
	
	for(i in 1:3){
		segments(xs[i], good[i]+1.96*gse[i], xs[i], good[i]-1.96*gse[i], lty=2)
			segments(xs[i]+seg, bad[i]+1.96*bse[i], xs[i]+seg, bad[i]-1.96*bse[i], lty=2)

	}
	
legend("topleft", legend=c("Good News", "Bad News"), pch=c(19, 24), cex=.8)	

######################################################################################################
#####################################################################################################

## Figure N.1
postscript("Figures/VignetteBarGraph.eps")
library(Hmisc)
heights=c(4.074497, 4.208984, 4.479508)
sd=c(2.037053, 2.053981, 2.019283)
n=c(1490, 1536, 1464)
bp=barplot(heights, ylim=c(3.5,4.8), ylab="Feeling thermometer (1 to 7)",xpd=FALSE)
print (bp)
print (bp[,1])
se=c(1.96*sd/sqrt(n))
lower=c(heights-se)
upper=c(heights+se)
errbar(bp[,1], heights, upper, lower, add=T)
axis(1, at=bp[,1], labels=c("Control", "Legislative", "Transfers"))
axis(1,at=c(0,5),labels=rep("",2))

dev.off()