
/*

Replication Materials for When Does Information Influence Voters? The Joint Importance of Salience and Coordination
Claire Aida, Jessica Gottlieb, Eric Kramon, and Gwyneth McClendon

July 5, 2019


*******************************
* Datasets

This file requires five datasets:

	survey_merge.dta -- includes survey data
	merged_administrative.dta -- includes official results data
	communes.csv -- information about the party of each incumbent
	candidate2015_ethnicities.dta -- information on ethnicities of party lists (for appendix)
	villages060415.dta -- information on village-level electoral results to get at incumbent party and electoral competitiveness (for appendix)
	
All Data files are saved in the Data folder included with these files
	
*******************************
* Dependencies	
	
This file requires outreg2, esttab, carryforward, and grc1leg2, center, listtex
		can be installed by typing: ssc install outreg2
									ssc install estout
									findit grc1leg2
									ssc install carryforward
									ssc install center
									ssc install listtex

*******************************
* Stata Version									
This file was created and run using Stata/SE 15.1


*******************************
* Other information

This file reads in do files that are saved in the Do folder
The first two do files prepare the original data files for analysis, creating the main variables
The remaining files create the results presented in the main body and appendix of the article

NOTE:  The working directory should include the following folders:
	Data -- includes the data files and a temp folder that stores the working data
	Tables -- folder where Tables will be exported
	Figures -- folder where figures will be exported


*/

****
* Install requires package

*ssc install center
*ssc install outreg2 // required to produce regression tables
*ssc install estout
*ssc install carryforward
*findit listtex 
*findit grc1leg2

************************************************
* Set working directory to folder with Data and Do folders
capture cd "/Users/gm1143/Dropbox/Disseminators/Benin/Drafts/GoodNewsBad/Submissions/CPS/Final documents/Replication Files"
capture cd "~/Dropbox/Disseminators/Benin/Drafts/GoodNewsBadNews/Submissions/CPS/Final documents/Replication Files"
capture cd "Dropbox/Research/Disseminators/Benin/Drafts/GoodNewsBadNews/Submissions/CPS/Final documents/Replication Files"
capture cd "/users/claireadida/Dropbox/Disseminators/Benin/Drafts/GoodNewsBadNews/Submissions/CPS/Final documents/Replication Files"
 capture cd "/users/ekramon/Dropbox/Disseminators/Benin/Drafts/GoodNewsBad/Submissions/CPS/Final documents/Replication Files"


set more off

**********************************************************
* 1 -- Prepare variables from survey for analysis

	* open survey data
	use "Data/survey_merge.dta", clear

	* Run do file
	do Do/01_survey_clean.do
	
	* Save cleaned survey data for use later
	save Data/temp/survey, replace
	
*************************************************************
**********************************************************
* 2 -- Prepare variables from official results for analysis

	** Open data
	use "Data/merged_administrative", clear

	* Run do file
	do Do/02_official_clean.do
	
	* Save cleaned survey data for use later
	saveold Data/temp/official, replace version(12) 
		* saving as version 12 so can open in R using "foreign" package

*************************************************************
**********************************************************
* 3 -- Main Results

	* Tables 2 and 3: Mean Incumbent Party Vote Share by Treatment Arm for Positive Information (2) and Negative Information (3)
	use Data/temp/official, clear
	do Do/03_official_meanincumbshare.do
	
	* Table 4: Impact of Positive Information on Incumbent Vote Share
	use Data/temp/official, clear
	do Do/04_official_impactposinfo.do
	
	* Figure 2: Effect of Joint Coordination and Salience Treatments on Incumbent Party Vote Share, by Incumbent Performance
	use Data/temp/official, clear
	do Do/05_official_saliencecoordbyperformance.do
	
	* Figure 3: Predicted Values by Treatment Condition and Incumbent Performance in High Dosage Communes 
	use Data/temp/official, clear
	do Do/06_official_predictedvalues.do
	
	* Figure 4: Effect of Salience Treatment on Expected Incumbent Party Vote Share in Village, by Dosage and Incumbent Performance
	use Data/temp/survey, clear
	do Do/07_survey_expectedincumbvoteshare.do
	
	* Table 5: Pre-treatment Correlates of Voting for the Incumbent
	use Data/temp/official, clear
	do Do/08_official_correlatesofincumbvote.do
	

*************************************************************
**********************************************************
* 4 -- APPENDIX (additional results and robustness tests)

	do Do/09_appendix.do 	
