
set more off

/*
NOTE ON SURVEY DATA: About 6000 people were surveyed at baseline.  
Another 6000 were treated (publicly or privately), but were not surveyed
About 3000 are in the sample at endline
*/


**** Treatment variables ********
	
tab condition, missing

	gen control=0 if condition=="T1T4"|condition=="T1T3"|condition=="T2T3"|condition=="T2T4"
	replace control=1 if condition=="Control + Survey"
	tab control ,missing

	gen public=.
	replace public=1 if condition=="T1T4" | condition=="T2T4"
	replace public=0 if condition=="T1T3" | condition=="T2T3" | control==1
	tab public, missing

gen private=.
replace private=1 if condition=="T1T3" | condition=="T2T3"
replace private=0 if condition=="T1T4" | condition=="T2T4" | control==1
tab private, missing

gen civics=.
replace civics=1 if condition=="T2T3" | condition=="T2T4"
replace civics=0 if condition=="T1T3" | condition=="T1T4" | control==1
tab civics, missing

gen infoonly=.
replace infoonly=1 if condition=="T1T3" | condition=="T1T4"
replace infoonly=0 if condition=="T2T3" | condition=="T2T4" | control==1
tab infoonly, missing

gen treatment=0
replace treatment=1 if control!=1
tab treatment, missing

encode condition, gen(condition_numeric) // private is 2 and 4, public is 3 and 5, control is 1
tab condition_numeric, missing nolabel

tab typet3 if condition=="T1T3" | condition=="T2T3", missing 
tab typet3 if condition=="T1T3" | condition=="T2T3", missing nolabel // what type of respondent are you recruiting for T3 villages? 1 is survey + intervention; 2 is survey only; 3 is intervention only


tab typet4 if condition=="T1T4" | condition=="T2T4", missing 
tab typet4 if condition=="T1T4" | condition=="T2T4", missing nolabel // what type of respondent are you recruiting for T4 villages? 1 is survey + invitation; 2 is invitation only


gen controlinprivate=0
replace controlinprivate=1 if typet3==2

generate nosurvey=0
replace nosurvey=1 if typet3==3 | typet4==2


**** Indicator for block
replace block = 4 if dosage==0 // villages in low dose all in same block

egen blid = group(commune block)  // generate block that combines block/commune


****** DV: vote for incumbent party at endline
* also do self reported turnout (for appendix)

tab endlineeq6
recode endlineeq6 (98 99 = .), gen(incumbent_vote)

recode endlineeq3 (98 99 3= .), gen(turnout)

*label var incumbent_v "Vote share for the incumbent"
label var condition_numeric "Treatment condition"
label var public "Public treatment"
label var private "Private treatment"
label var civics "Civic + performance information"
label var infoonly "Performance information only"
label var treatment "Received any treatment"
label var main_index "Overall performance score"
label var dosage "Dosage"

label define treat 0 "Control" 1 "Treatment"
label values treatment treat

label define dose 0 "Low" 1 "High"
label values dosage dose

***ONE-TO-ONE-MAPPING: could villagers identify the principal deputy on average? Yes.
decode surveycb22 if surveycb22~=999, generate(deputynamebaseline) maxlength(80)
gen dnamecorrect=.
replace dnamecorrect=1 if dname==deputynamebaseline
replace dnamecorrect=0 if surveycb22==999
replace dnamecorrect=0 if surveycb22~=999 & surveycb22~=. & deputynamebaseline~=dname
sum dnamecorrect
tab dnamecorrect condition, column // 57-60% across conditions correctly identified their incumbent 

gen dkanydeputy=0
replace dkanydeputy=1 if surveycb22==999

tab dnamecorrect dkanydeputy, cell

***********************************************
** Define "good" information, relative to priors
	** If don't know, we code based on whether legislator was better or worse than local
	** If priors = information, we code based on whether prior was negative or positive
		* rational is information would strengthen belief in prior if the same

recode surveycb29 (99=.) (4=1) (3=2) (2=3) (1=4), gen (performanceplenary) 
recode surveycb31 (99=.) (4=1) (3=2) (2=3) (1=4), gen (performancecommittee) 
recode surveycb33 (99=.) (4=1) (3=2) (2=3) (1=4), gen (performanceboth) 
		
tab performanceboth, missing // this is the prior on overall performance, ranging from 1 (worst prior) to 4 (best prior)
rename overall_departememt overall_departement
tab overall_departement, missing // this is the info we provided, ranging from 1 (best perf) to 4 (worst perf)
recode overall_departement (99=.) (4=1) (3=2) (2=3) (1=4), gen (overall_dept_recode)
gen goodnewsrelative2=1 if (performanceboth==1 & overall_dept_recode>1) | (performanceboth==2 & overall_dept_recode>2) | (performanceboth==3 & overall_dept_recode>2) | (performanceboth==4 & overall_dept_recode==4)
replace goodnewsrelative2=0 if (performanceboth==1 & overall_dept_recode==1) | (performanceboth==2 & overall_dept_recode<3) | (performanceboth==3 & overall_dept_recode<3) | (performanceboth==4 & overall_dept_recode<4)
replace goodnewsrelative2=1 if (performanceboth==. & overall_dept_recode==3) | (performanceboth==. & overall_dept_recode==4)
replace goodnewsrelative2=0 if (performanceboth==. & overall_dept_recode==2) | (performanceboth==. & overall_dept_recode==1)
tab goodnewsrelative2, missing
summarize goodnewsrelative2

** Also create good news measure that corresponds with Admin
	* not conditional on priors

gen goodnews = 0 if overall_dept_recode==1 | overall_dept_recode==2
	replace goodnews = 1 if overall_dept_recode==3 | overall_dept_recode==4


********************************************
** Create dummy indicators for each Prior category (to use as control)
capture tab surveycb33, gen(p)	 // overall prior -- will include control that also has indicator for don't knows
label variable p1 "Prior --- Much better"
label variable p2 "Prior --- A little better"
label variable p3 "Prior --- A little worse"
label variable p4 "Prior --- Much worse"
label variable p5 "Prior --- Do not know"

****************************************************
** ***** Measure of of prior vote for incumbent (partisanship) 

** Merge in information about the incumbent's political party
tempfile temp2
save `temp2', replace

insheet using "Data/communes.csv", names clear
rename commune_key commune
rename party incumbent_party2011

sort commune

merge 1:m commune  using `temp2'

tab incumbent_party2011
tab surveycb19

generate votedincumbent2011=0 if surveycb18==1
replace votedincumbent2011=1 if surveycb19=="FCBE" & incumbent_party=="FCBE"
replace votedincumbent2011=1 if surveycb19=="Cauris" & incumbent_party=="FCBE"
replace votedincumbent2011=1 if surveycb19=="UN" & incumbent_party=="UN"
replace votedincumbent2011=1 if surveycb19=="G13" & incumbent_party=="G13"
replace votedincumbent2011=1 if surveycb19=="AFU" & incumbent_party=="AFU"
replace votedincumbent2011=1 if surveycb19=="UPR" & incumbent_party=="FE UPR"

label var votedincumbent2011 "2011 Incumbent Vote"

	
*****************************************
** Other individual level vars for balance, etc

recode surveycb4 (2=1) (1=0), gen(female)

gen age=surveycb5 if surveycb5>18 & surveycb5<100

encode surveycb9, gen(ethnicity_numeric)

encode surveycb6, gen(language)

gen educyears=surveycb7

gen coethnic= surveycb24
	label variable coethnic "Coethnic with incumbent"

gen conseil_chef = surveycb12a
	label variable conseil_chef "Member of chief's council"
gen professional =  surveycb12b
	label variable professional "Member of professional assoc."
gen jeunes= surveycb12c
	label variable jeunes "Member of youth assoc."
gen womens_group= surveycb12d
	label variable womens_gr "Member of women's assoc."
gen politique= surveycb12e
	label variable politique "Member of political assoc."
	
tab surveycb13, gen(information_source)
	label variable information_source1 "Information from radio"
	label variable information_source2 "Information from newspaper"
	label variable information_source3 "Information from television"
	label variable information_source4 "Information from friends"

tab surveycb14, gen(discuss)
	label variable discuss1 "Never discuss politics"
	label variable discuss2 "Sometimes discuss poltics"
	label variable discuss3 "Often discuss politics"

recode surveycb21 (3 4 = 1) (1 2 = 0), gen(secret_ballot)
	 tab secret surveycb21
	 label variable secret "Ballot secrecy can be violated"

gen know_village_vote= surveycb42
	label variable know_village_ "Parties know how the village voted"

gen consequences =surveycb43
	label variable consequences "Consequences if village does not support a party"

gen help= surveycb27
	label variable help "Received Help"

recode  surveycb33 (1 2 = 1) (3 4 =0) (99 = .), gen(overall_prior)
	label variable overall_prio "Positive Overall Prior"

recode  surveycb35 (1 2 = 1) (3 4 =0) (99 = .), gen(effort_prior)
	label variable effort_prio "Positive prior about effort of incumbent"
	
recode  surveycb36 (1 2 = 1) (3 4 =0) (99 = .), gen(corruption_prior)
	label variable corruption_prio "Would be surprised to hear about incumbent corruption"



label variable urban "Urban"
label variable margin "Vote margin (top 2 parties) in previous election"


label variable assembly_index  "Incumbent score on plenary index"
label variable committee_index  "Incumbent score on committee index"
label variable main_index "Incumbent score overall index"
label variable female "Female"

label variable educyears "Years of education"
label variable age "Age"

label var treatment "Treatment"
******************
	************ Access to electricity ************

tab surveycb60, missing

gen electricity_type=surveycb60
replace electricity=1 if electricity_type==1 |electricity_type==2|electricity_type==6
replace electricity=0 if electricity_type==3 | electricity_type==4 | electricity_type==5| electricity_type==7| electricity_type==8

tab electricity

************ Material of House ************

tab surveycb58, missing

gen materialh=surveycb58
gen house=.

replace house=1 if materialh=="A cot√© d'un mur" | materialh=="A c√¥t√©  d'un  mur"  | materialh=="A c√¥t√©  d'un mur" | materialh=="A c√¥t√© d'un  mur" | materialh=="A c√¥t√© d'un mur"

replace house=2 if materialh=="A c√¥t√©  d'un apattam" | materialh=="Apatam"  | materialh=="Apattam" | materialh=="Appatam" | materialh=="Sous un appatam" | materialh=="Sous  apattam" ///
| materialh=="Sous  appatam" | materialh=="Sous apatam" | materialh=="Sous apattam" | materialh=="Sous appatam"

replace house=3 if materialh=="Mat√©riaux  pr√©caire" | materialh=="Mat√©riaux  pr√©caires" | materialh=="Mat√©riaux primaire" | materialh=="Mat√©riaux pr√© caires" | materialh=="Mat√©riaux pr√©caire" | materialh=="Mat√©riaux pr√©caires" 

replace house=4 if materialh=="Avec  du ciment" | materialh=="Ciment" | materialh=="Briques en ciment" | materialh=="Briques des  ciment" | materialh=="Briques de ciment" | materialh=="Brique de ciment"  

replace house=5 if materialh=="Bambou" | materialh=="En bambou"

replace house=6 if materialh=="Argil" | materialh=="Argile" | materialh=="Bamko" | materialh=="Boue" | materialh=="Banci" | materialh=="Banco" | materialh=="Banka"|materialh=="Banko"| materialh=="Banvo" ///
|materialh=="Brique en  banco"| materialh=="Brique en banco" | materialh=="Barre de terre" | materialh=="Brique  de terre" | materialh=="Brique de terre" ///
| materialh=="Brique de terre battue" | materialh=="Brique de terre battu"| materialh=="Brique de terre, terre battue" | materialh=="Brique de terre,terre battue" ///
| materialh=="Brique" | materialh=="Bique" | materialh=="Brique en banco et en terre  battue " | materialh=="Brique en terre battue" | materialh=="Brique et terre" ///
| materialh=="Brique et terre battue"| materialh=="Brique terre battue" | materialh=="Briques" | materialh=="Briques  de terre en battue" | materialh=="Briques  en terre battue" ///
| materialh=="Briques  et terre batu" | materialh=="Briques  stabilis√©e" | materialh=="Briques de terre  battue" | materialh=="Briques de terre battu" | materialh=="Briques de terre battue" ///
| materialh=="Briques en terre  battue"| materialh=="Briques en terre battue" | materialh=="Briques en terre batu" | materialh=="Briques et terre- battue" | materialh=="Briques rouge" ///
| materialh=="Briques terre battue" | materialh=="Brque" | materialh=="Bsnco" | materialh=="Clai" | materialh=="Dans une cl√¥ture en brique" | materialh=="Demi banko" | materialh=="En banco" ///
| materialh=="En banko" | materialh=="En clai" | materialh=="En clair" | materialh=="En claire" | materialh=="En terre battu" | materialh=="En terre battue" | materialh=="Maison a terre battue" ///
| materialh=="Tere battu" | materialh=="Tere battue" | materialh=="Tere batu" | materialh=="Terr batu" | materialh=="Terre" | materialh=="Terre  battu" | materialh=="Terre  battue" ///
| materialh=="Terre  battur" | materialh=="Terre  battute" | materialh=="Terre  batu" | materialh=="Terre  batue" | materialh=="Terre  brique" | materialh=="Terre  briques" ///
| materialh=="Terre  b√¢t u" | materialh=="Terre  b√¢ti" | materialh=="Terre  b√¢tie"| materialh=="Terre  b√¢tu"| materialh=="Terre  de barre" | materialh=="Terre  p√©trie" ///
| materialh=="Terre  rouge" | materialh=="Terre -battue" | materialh=="Terre De barre" | materialh=="Terre argileuse" | materialh=="Terre battu" | materialh=="Terre battue" ///
| materialh=="Terre battue ,brique de terre" | materialh=="Terre battue,brique de terre" | materialh=="Terre battues" | materialh=="Terre batu" | materialh=="Terre batue" ///
| materialh=="Terre batues" | materialh=="Terre b√¢ti" | materialh=="Terre b√¢tie" | materialh=="Terre b√¢ttue" | materialh=="Terre b√¢tu" | materialh=="Terre de barre" ///
| materialh=="Terre de bas" | materialh=="Terre et briques" | materialh=="Terre p√©tri" | materialh=="Terre p√©trie" | materialh=="Terre rouge" | materialh=="Terre stabilis√©e" ///
| materialh=="Terre terre" | materialh=="Terre √† barre" | materialh=="Terre,battu" | materialh=="Terre- battu" | materialh=="Terre- battue" | materialh=="Terre-battue" ///
| materialh=="Terre-battue  et brique" | materialh=="Terre-p√©trie" | materialh=="Terrebattue" | materialh=="Terrebuttue" | materialh=="Terres" | materialh=="Terres  batues" ///
| materialh=="Terres  briques" | materialh=="Terres  et brique" | materialh=="Terres batues" | materialh=="Terrr battue" | materialh=="Terry" | materialh=="Terr√© battue" ///
| materialh=="Terte battue" | materialh=="Tertes batues" | materialh=="T√™rre" | materialh=="battu" 

replace house=7 if materialh=="Briques de terre  battue + ciment" | materialh=="Briques de terre battue + ciment" | materialh=="Briques de terre battue +ciment" ///
| materialh=="Briques dee terre battue + ciment" | materialh=="Briques dr terre  battue +ciment" | materialh=="Briques dr terre  battue +ciment" | materialh=="Briques terre battue + ciment" ///
| materialh=="Briques terre battue +ciment" | materialh=="M√©lange de ciment et terre battu" | materialh=="Terre battu+ciment" 

replace house=8 if materialh=="Bois" 

replace house=9 if materialh=="Toile" | materialh=="Tole"

replace house=10 if materialh=="Dur" | materialh=="Dure" | materialh=="En briques dures" | materialh=="En dur" | materialh=="En dure" | materialh=="Endur" | materialh=="Endure" 

replace house=11 if materialh=="Pagne" 

replace house=12 if materialh=="MATERIAUX Definitifs" | materialh=="Mat√©riaux  definitif" | materialh=="Mat√©riaux  definitifs" | materialh=="Mat√©riaux  defitifs" | materialh=="Mat√©riaux  d√©finitif" ///
 | materialh=="Mat√©riaux  d√©finitifs" |  materialh=="Mat√©riaux definitifs" | materialh=="Mat√©riaux d√©finitif" | materialh=="Mat√©riaux d√©finitifs"

replace house=13 if materialh=="Paillasson" | materialh=="Paille" | materialh=="Pailles" | materialh=="Chaume"  | materialh=="Sous un paillotte" | materialh=="Sous paillotte" 

replace house=14 if materialh=="Mat√©riaux  pr√©caire" | materialh=="Mat√©riaux  pr√©caires" | materialh=="Mat√©riaux primaire" | materialh=="Mat√©riaux pr√© caires" | materialh=="Mat√©riaux pr√©caire" | materialh=="Mat√©riaux pr√©caires" 

replace house=15 if materialh=="Mat√©riaux  locaux" | materialh=="Mat√©riaux locaux" 

tab house, missing


/*
1=Side wall
2=Apattam
3=Palm trees, under a tree, under a palm
4=Cement or Cement Bricks
5=Bamboo
6=MUD AND CLAY
7=mud/clay and cement
8=Wood
9=Metal Sheet
10=Hard material
11= cloth
12=Definitive materials
13=Straw
14=precarious materials
15= Local materials

*/

gen house_poverty=.

replace house_poverty=1 if house==2 | house==3 | house==11 | house== 13 | house==14


replace house_poverty=2 if house==6 | house==5 | house==8

replace house_poverty=3 if house==7 | house==8 

replace house_poverty=4 if house==4 | house==10 | house==12 
/*
house_poverty: 1-4 (lower values indicate more poverty)
1- Apattam, Palm trees, under a tree, under a palm, cloth, straw, precarious materials.
2- Mud, Clay, Mud and Clay, Bricks, 
3- Mud/CLay mixed with Cement, Wood
4- Cement, Hard Materials, Definitive materials, Metal sheet (1 observation). 
*/

label variable house_pover "Poverty (housing material)"

************ Material of Roof ************

gen roofmat=surveycb59
gen roof=.

replace roof=1 if roofmat=="Apattam"

replace roof=2 if roofmat=="Banco" | roofmat=="Banko" | roofmat=="Brigue" | roofmat=="Brique de terre" ///
| roofmat=="Briques" | roofmat=="T" | roofmat=="Terre" | roofmat=="Terre battu" | roofmat=="Terre battue" | roofmat=="Terre p√©trie" 

replace roof=3 if roofmat=="Chaume" | roofmat=="En feuille de branche" | roofmat=="Des paille" | roofmat=="En feuille de branche" ///
| roofmat=="En paille" | roofmat=="Feuille de paille" | roofmat=="Feuille de palme" | roofmat=="Feuille du  palme" ///
| roofmat=="Feuilles  de branche" | roofmat=="Paill" | roofmat=="Paillasson" | roofmat=="Paille" | roofmat=="Pailles" 

replace roof=4 if roofmat=="Feuille de tole" | roofma=="Feuilles  de tole" | roofmat=="Feuilles  de toles" ///
| roofmat=="Feuilles  de t√¥le" | roofmat=="Feuilles de toles" | roofmat=="Feuilles de toltes" ///
| roofmat=="Feuilles, de toles" | roofmat=="Les toles" | roofmat=="Toil" | roofmat=="Toile" | roofmat=="Toke" ///
| roofmat=="Tol" | roofmat=="Tole" | roofmat=="Tole  ondulee" | roofmat=="Tole ondulee" | roofmat=="Tole ondul√©e" ///
| roofmat=="Toles" | roofmat=="Tolle" | roofmat=="Tolles" | roofmat=="Tolr" | roofmat=="Tol√©r√©" | roofmat=="To√Æl" 

replace roof=5 if roofmat=="Tuile" | roofmat=="Tuiles" | roofmat=="Tule" | roofmat=="Tules" | roofmat=="Tulle" ///
| roofmat=="Turle" | roofmat=="T√¥ke" | roofmat=="T√¥le" | roofmat=="T√¥le  dalles" | roofmat=="T√¥le  et dalles" ///
| roofmat=="T√¥le T√¥le" | roofmat=="T√¥le de" | roofmat=="T√¥le et paille" | roofmat=="T√¥le et  paille" ///
| roofmat=="T√¥le ondulee" | roofmat=="T√¥le ondul√©e" | roofmat=="T√¥les" | roofmat=="Y T√¥le" 

replace roof=6 if roofmat=="Ciment"

replace roof=7 if roofmat=="Pagne" 

/* 
1=apattam
2= mud or clay
3= straw, branches, palms
4= metal sheet 
5=Tiles
6= cement
7=cloth
*/

gen roof_poverty=.

replace roof_poverty=1 if roof==1 | roof==3 | roof==6 | roof==7

replace roof_poverty=2 if roof==2 | roof==4 

replace roof_poverty=3 if roof==5

replace roof_poverty=4 if roof==6

tab roof_poverty, missing

***** Create index of poverty

* Run little program for creating Anderson indices
do Do/genindex.do

genindex roof_poverty house_poverty electricity, nv(poverty)

replace povertyA=povertyA*-1
**Higher values of povertyA indicate more poverty (lower income) 


label variable school1 "School in the community"
label variable borehole1 "Borehole in the community"
label variable clinic1 "Health clinic in the community"



******
** Re-order variables so cleaned vars are at the top

order commune quartier blid treatment treatment condition incumbent_vote turnout  dnamecorrect dkanydeputy coethnic female age urban educyears house_ electricity coethnic margin conseil_chef professional jeunes womens_group politique ///
	information_source1-information_source4 discuss1-discuss3 secret know_village_  ///
	consequences help goodnewsrelative2 goodnews votedincumbent2011 overall_prior effort_prior corruption_prior p1-p4 ///
	school1 clinic1 borehole1
