
** This file cleans and creates variables from official results

set more off

***********************
* DEFINE CONDITIONS

gen original_block = block

replace condition="Control" if condition=="control"

replace condition="Control" if condition==""

generate public=0 
	replace public=1 if condition=="T1T4" | condition=="T2T4"

generate civics=0 
	replace civics=1 if condition=="T2T3" | condition=="T2T4"

gen private=0
	replace private=1 if condition=="T1T3" | condition=="T2T3"

gen infoonly=0
	replace infoonly=1 if condition=="T1T3" | condition=="T1T4"

drop treatment 
gen treatment=0
	replace treatment=1 if condition!="Control"
	
gen Control=0
	replace Control=1 if condition=="Control"

replace condition_numeric=1 if condition_numeric==.

generate commonarm=.
replace commonarm=0 if Control==1
replace commonarm=1 if condition=="T1T3"

gen dose_civics = dosage*civics
label variable dose_civics "High Dosage x Civics"	


gen t1t3 = 0 if condition!=""
	replace t1t3 = 1 if condition=="T1T3"
	label variable t1t3 "Info Only -- Private"


gen t1t4 = 0 if condition!=""
	replace t1t4 = 1 if condition=="T1T4"
	label variable t1t4 "Info Only -- Public"	


gen t2t3 = 0 if condition!=""
	replace t2t3 = 1 if condition=="T2T3"
	label variable t2t3 "Info + Civics -- Private"	

gen t2t4 = 0 if condition!=""
	replace t2t4 = 1 if condition=="T2T4"
	label variable t2t4 "Info + Civics -- Public"
	
************************************************************

label var commonarm "Common arm"
label var incumbent_share "Vote share for the incumbent"
label var condition_numeric "Treatment condition"
label var public "Public treatment"
label var private "Private treatment"
label var civics "Civic + performance information"
label var infoonly "Performance information only"
label var treatment "Received any treatment"
label var main_index "Overall performance score"
label var overall_prior "Positive prior about incumbent performance"
label var corruption_prior "Would be surprised to hear incumbent corrupt"
label var area "Urban"
label var dosage "Dosage"


label define treat 0 "Control" 1 "Treatment"
label values treatment treat

label define dose 0 "Low" 1 "High"
label values dosage dose

gen block_orig = block

*DEFINE BLOCKS AND SIZE
replace block = 4 if dosage==0 // villages in low dose all in same block

tab block_orig urban
tab block_orig

gen rural  = 0 if block_ori ==1
	replace rural =1 if block_or==2|block_o==3

egen blid = group(commune block)  // generate block that combines block/commune

** Create commune x treatment variable for clustering SEs

encode commune, gen(cid)

gen newid=cid*100 + condition_numeric

*CREATE TURNOUT VARIABLE AND STANDARDIZED REGISTERED VOTERS
egen zvoters=std(regvoters)
label var zvoters "Registered voters"
xtile quart = zvoters, n(4)
label var quart "Voters quartile"

egen zvoters1=std(50/regvoters)
label var zvoters1 "Share village treated"

** Create measure of turnout
drop turnout
generate turnout=(total_valid+total_annulees)/regvoters
label var turnout "Voter turnout"
replace turnout=. if turnout>1 //31 Control villages and 1 T2T4
	
** Create log of registered voters (for balance and descrptives)
gen lg_voters = log(regvoters)
*hist lg_voters	

******************************	
** Create measures of village coethnicity with incumbent
	* based off of proportion of survey respondents in village that are coethnics
	** coethnic variable is this proportion
	
gen co_50 = 0 if coethnic < .5 & coethnic~=.
	replace co_50 = 1 if coethnic > .49 & coethnic~=.
	tab  co_50

	label variable co_50 "Coethnic village (50 percent)"
	
gen co_70 = 0 if coethnic < .7 & coethnic~=.
	replace co_70 = 1 if coethnic > .69 & coethnic~=.
	tab  co_70

		label variable co_70 "Coethnic village (70 percent)"

	
gen co_90 = 0 if coethnic < .9 & coethnic~=.
	replace co_90 = 1 if coethnic > .89 & coethnic~=.
	tab  co_90	
		label variable co_90 "Coethnic village (90 percent)"
		


**********************

order commune village treatment co_50 co_70 co_90 coethnic blid newid ///
	lg_voters area competitive_margin margin main_index school1 clinic1 borehole1
	
	
