
** This file recreates Tables 2 and 3 from the main paper

set more off

***
** Drop those that did not match
keep if merge2015==3


***********************
/*Deal with ADJOZOUNME which got both treatments, T1T3 and T1T4 on different days. 
This will be reflected in our raw data table of mean conditions, but in later analyses so as not to double count, 
we always assume ADJOZOUNME received just one, T1T3, or the lesser of the treatments. In the public vs. private 
regression, we drop ADJOZOUNME altogether.
*/

expand 2 if village=="ADJOZOUNME"
duplicates list village commune
duplicates tag village commune, generate(dtag)
gsort -dtag
replace dtag=_n if dtag!=0
replace condition="T1T4" if dtag==2

global conditions Control T1T3 T1T4 T2T3 T2T4 

foreach con in $conditions{
estpost su incumbent_share  if condition=="`con'" & dosage==1 & incumbent_share!=. & goodnews==1
est store `con'
capture estpost su incumbent_share  if condition=="`con'" & dosage==0 & incumbent_share!=. & goodnews==1
est store `con'LD
}
esttab ControlLD T2T4LD $conditions  using "Tables/summ_admin_good2_2.tex", replace  ///
	cells(mean(fmt(3)) sd(par fmt(3))) label booktabs nonum gaps mtitles collabels(none) ///
	title (Mean Incumbent Vote Share by Treatment Arm for Positive Information \label{tab:summadmin_good}) ///
	addnote("Standard deviations in parentheses. LD in the column title signifies low dosage treatment.") sub("{l*{7}{c}}" "{l*{2}{c}|*{5}{c}}")

foreach con in $conditions{
estpost su incumbent_share  if condition=="`con'" & dosage==1 & incumbent_share!=. & goodnews==0
est store `con'
capture estpost su incumbent_share  if condition=="`con'" & dosage==0 & incumbent_share!=. & goodnews==0
est store `con'LD
}
esttab ControlLD T2T4LD $conditions  using "Tables/summ_admin_bad2_2.tex", replace  ///
	cells(mean(fmt(3)) sd(par fmt(3))) label booktabs nonum gaps mtitles collabels(none) ///
	title (Mean Incumbent Vote Share by Treatment Arm for Negative Information \label{tab:summadmin_bad}) ///
	addnote("Standard deviations in parentheses. LD in the column title signifies low dosage treatment.") sub("{l*{7}{c}}" "{l*{2}{c}|*{5}{c}}")

drop if village=="ADJOZOUNME" & dtag==2
drop dtag
