
** Recreates Results Tables and Figures for Appendix for When Does Information Influence Voters? The Joint Importance of Salience and Coordination

***********************************
set more off

use Data/temp/official, clear

***********************************
***Appendix C: Balance Tests*******
***********************************

** Table C.1
gen unmatched=.
replace unmatched=1 if merge2015==1
replace unmatched=0 if merge2015==3
tab unmatched

tab unmatched dosage if (condition=="" | condition=="control") & survey_sample==0, column

ttest dosage, by(unmatched) unequal
ttest survey_sample, by(unmatched) unequal

ttest inscrits, by(unmatched) unequal
ttest votants, by(unmatched) unequal
ttest voteshare_fcbe, by(unmatched) unequal
ttest area, by(unmatched) unequal
ttest participation, by(unmatched)
ttest margin, by(unmatched) unequal
ttest competitive_margin, by(unmatched) unequal
ttest north_south, by(unmatched) unequal
ttest main_index, by(unmatched) unequal


gen lg_inscrits = log(inscrits)

logit unmatched lg_inscrits voteshare_fcbe area participation competitive_margin main_index north_south
estimates store unconstrained
logit unmatched if lg_inscrits!=. & voteshare_fcbe!=. & area!=. & participation!=. & competitive_margin!=. & main_index!=. & north_south!=.
lrtest unconstrained

matrix define hist=J(6, 5, .)
matrix colnames hist = "Mean Unmatched" "Mean Matched" "Difference" "P-Value"    
matrix rownames hist = "Registered Voters (log)" "Urban" "Turnout" "Competitive (dichotomous)" "Incumbent Performance" "North" 

local i = 0			   
foreach var in lg_inscrits area participation competitive_margin main_index north_south {
	local i = `i' + 1
	qui regress `var' unmatched, cluster(commune)
	local a = _b[_cons] + _b[unmatched]
	display `a'
	matrix hist[`i', 1] = round(`a', .01)
	matrix hist[`i', 2] = round(_b[_cons], .01)
	matrix hist[`i', 3] = round(abs(_b[unmatched]), .01)
	matrix temp = r(table)
	local p = temp[4, 1]
	display `p'
	matrix hist[`i', 4] = round(`p', .01)

}			   
			   
matrix list hist

cap esttab m(hist) using Tables/unmatched_balance_admin.tex, replace nomtitle ///
	addnote("P-values generated from tests in which we cluster on commune.")

**Table C.2

* Drop those that did not match

* Change two very high vote margins in low dosage to missing
replace margin = . if margin > 1

matrix define hist=J(5, 4, .)
matrix colnames hist = "Mean High Dosage" "Mean Low Dosage" "Difference" "P-Value"    
matrix rownames hist = "Registered Voters (log)" "Urban" "Competitive (dichotomous)" ///
		       "Vote Margin" "Overall Performance" 

local i = 0			   
foreach var in lg_voters area competitive_margin margin main_index {
	local i = `i' + 1
	qui regress `var' dosage, cluster(commune)
	local a = _b[_cons] + _b[dosage]
	display `a'
	matrix hist[`i', 1] = round(`a', .01)
	matrix hist[`i', 2] = round(_b[_cons], .01)
	matrix hist[`i', 3] = round(abs(_b[dosage]), .01)
	matrix temp = r(table)
	local p = temp[4, 1]
	display `p'
	matrix hist[`i', 4] = round(`p', .01)

}			   

tab condition_numeric, gen(tr)
			   
matrix list hist

esttab m(hist) using Tables/dosage_balance_admin.tex, replace nomtitle ///
	addnote("P-values generated from tests in which we cluster on commune.")
	

*** Table C.3

matrix define hist=J(10, 5, .)
matrix colnames hist = "Control" "Info Only/Private" "Info Only/Public" "Civics/Private" "Civics/Public"   
matrix rownames hist = "Registered Voters (log)" " " "Urban" " " "Competitive (dichotomous)" " " ///
		       "Vote Margin" " " "Overall Performance" " "
	
local i = -1	
local j = 0		   
foreach var in regvoters area competitive_margin margin main_index {
	local i = `i' + 2
	local j = `j' + 2

	qui regress `var' tr2-tr5 if dosage==1, cluster(commune)
	local a1 = _b[_cons] + _b[tr2]
	local a2 = _b[_cons] + _b[tr3]
	local a3 = _b[_cons] + _b[tr4]
	local a4 = _b[_cons] + _b[tr5]

	display `a'
	matrix hist[`i', 1] = round(_b[_cons], .01)
	matrix hist[`i', 2] = round(`a1', .01)
	matrix hist[`i', 3] = round(`a2', .01)
	matrix hist[`i', 4] = round(`a3', .01)
	matrix hist[`i', 5] = round(`a4', .01)
	
	matrix temp = r(table)

	matrix hist[`j', 2] = round(temp[4, 1], .01)
	matrix hist[`j', 3] = round(temp[4, 2], .01)
	matrix hist[`j', 4] = round(temp[4, 3], .01)
	matrix hist[`j', 5] = round(temp[4, 4], .01)
}				
	
matrix list hist
	
esttab m(hist) using Tables/balance_high_dose.tex, replace nomtitle ///
	addnote("P-values generated from tests in which we cluster on commune.")	
	

*** Table C.4	
matrix define hist=J(5, 4, .)
matrix colnames hist = "Mean Treatment" "Mean Control" "Difference" "P-Value"    
matrix rownames hist = "Registered Voters (log)" "Urban" "Competitive (dichotomous)" ///
		       "Vote Margin" "Overall Performance" 

local i = 0			   
foreach var in regvoters area competitive_margin margin main_index {
	local i = `i' + 1
	qui regress `var' treatment if dosage==0
	local a = _b[_cons] + _b[treatment]
	display `a'
	matrix hist[`i', 1] = round(`a', .01)
	matrix hist[`i', 2] = round(_b[_cons], .01)
	matrix hist[`i', 3] = round(abs(_b[treatment]), .01)
	matrix temp = r(table)
	local p = temp[4, 1]
	display `p'
	matrix hist[`i', 4] = round(`p', .01)

}			   
			   
matrix list hist

esttab m(hist) using Tables/balance_low_dosage.tex, replace nomtitle 

************************************************
*Appendix F: The Impact of Negative Information*
************************************************

*** Table F.1
areg incumbent_share treatment   if goodnews==0&dosage==0, absorb(blid) vce(cluster newid)
	outreg2 using "Tables/res2a.tex", replace dec(3) ctitle("Low Dose") tex(fra) label sortvar(treatment) nonotes ///
		addnote("In parentheses, robust standard errors clustered by commune in model 1 and commune x treatment,"" , ""otherwise. Models include block fixed effects. *** p$<$0.01, ** p$<$0.05, * p$<$0.1.") ///
	
areg incumbent_share treatment  if goodnews==0 & dosage==1&civics==0, vce(cluster newid) absorb(blid)
	outreg2 using "Tables/res2a.tex", append dec(3) ctitle("High Dose", "No Civics") sortvar(treatment) tex(fra) label nonotes

areg incumbent_share private public  if goodnews==0 & dosage==1&civics==0, vce(cluster newid) absorb(blid)
	outreg2 using "Tables/res2a.tex", append dec(3) ctitle("High Dose", "No Civics") sortvar(treatment) tex(fra) label nonotes
	
areg incumbent_share infoonly civics  if goodnews==0 & dosage==1, vce(cluster newid) absorb(blid)
	outreg2 using "Tables/res2a.tex", append dec(3) ctitle("All High" , "Dose") sortvar(treatment) tex(fra) label nonotes
	test infoonly=civics
	
areg incumbent_share infoonly civics dose_civics  if goodnews==0, absorb(blid) vce(cluster newid)
	outreg2 using "Tables/res2a.tex", append dec(3) ctitle("All", "Communes") sortvar(treatment) tex(fra) label nonotes

	
************************************************
*Appendix G: Robustness Checks*
************************************************

*** Table G.1

use Data/temp/survey, clear
gen dose_civics = dosage*civics

areg incumbent_v treatment   if goodnewsrelative2==1&dosage==0&dnamecorrect==1, absorb(blid) vce(cluster quartier)
	outreg2 using "Tables/res1a_survey_knewdeputy.tex", replace dec(3) ctitle("Low Dose") tex(fra) label sortvar(treatment) nonotes ///
		addnote("In parentheses, robust standard errors clustered by village." ,   "Models include block fixed effects. *** p$<$0.01, ** p$<$0.05, * p$<$0.1.", "Includes only respondents who identified the incumbent as responsible for their commune.") ///
	
areg incumbent_v treatment  if goodnewsrelative2==1 & dosage==1 &dnamecorrect==1, vce(cluster quartier) absorb(blid)
	outreg2 using "Tables/res1a_survey_knewdeputy.tex", append dec(3) ctitle("High", "Dose") sortvar(treatment) tex(fra) label nonotes

areg incumbent_v infoonly civics  if goodnewsrelative2==1 & dosage==1&dnamecorrect==1, vce(cluster quartier) absorb(blid)
	outreg2 using "Tables/res1a_survey_knewdeputy.tex", append dec(3) ctitle("High" , "Dose") sortvar(treatment) tex(fra) label nonotes
	test infoonly=civics
	
	
areg incumbent_v private public  if goodnewsrelative2==1 & dosage==1&dnamecorrect==1, vce(cluster quartier) absorb(blid)
	outreg2 using "Tables/res1a_survey_knewdeputy.tex", append dec(3) ctitle("High" , "Dose") sortvar(treatment) tex(fra) label nonotes
	
	
areg incumbent_v infoonly civics dose_civics  if goodnewsrelative2==1 & dnamecorrect==1, absorb(blid) vce(cluster quartier)
	outreg2 using "Tables/res1a_survey_knewdeputy.tex", append dec(3) ctitle("All", "Communes") sortvar(treatment) tex(fra) label nonotes
	
***Figure G.1

*** Table G.2

use Data/temp/official, clear

* Main specification
	regress incumbent_share treatment i.blid  if goodnews==1 & dosage==0, vce(cluster newid)
		outreg2 using "Tables/lowdosage_robustness.tex", keep(treatment) dec(2) label replace ctitle("Main, Specification") nonotes ///
		addnote("In parentheses, robust standard errors clustered by commune." ,   "Models include block fixed effects. *** p$<$0.01, ** p$<$0.05, * p$<$0.1.") 
	
	* add weights
	regress incumbent_share treatment i.blid [pw=ipw] if goodnews==1 & dosage==0, vce(cluster newid)
		outreg2 using "Tables/lowdosage_robustness.tex", keep(treatment) dec(2) label append ctitle("Weights") nonotes

	* Remove block fixed effects and weights
	regress incumbent_share treatment  if goodnews==1 & dosage==0, vce(cluster newid)
		outreg2 using "Tables/lowdosage_robustness.tex", keep(treatment) dec(2) label append ctitle("No Fixed, Effects") nonotes 

	* Remove each commune one by one
	tab blid if goodnews==1&dosage==0 // 18, 19, 25, 30, 37, 57
	
	regress incumbent_share treatment i.blid  if goodnews==1 & dosage==0&blid!=18, vce(cluster newid)
		outreg2 using "Tables/lowdosage_robustness.tex", tex(fra) keep(treatment) dec(2) label append ctitle("Dangbo, Removed") nonotes

	regress incumbent_share treatment i.blid  if goodnews==1 & dosage==0&blid!=19, vce(cluster newid)
			outreg2 using "Tables/lowdosage_robustness.tex", tex(fra)keep(treatment) dec(2) label append ctitle("Dassa-Zoume, Removed") nonotes

	regress incumbent_share treatment i.blid  if goodnews==1 & dosage==0&blid!=25, vce(cluster newid)
			outreg2 using "Tables/lowdosage_robustness.tex", tex(fra) keep(treatment) dec(2) label append ctitle("Gogounou, Removed") nonotes

	regress incumbent_share treatment i.blid  if goodnews==1 & dosage==0&blid!=30, vce(cluster newid)
			outreg2 using "Tables/lowdosage_robustness.tex", tex(fra) keep(treatment) dec(2) label append ctitle("Kerou, Removed") nonotes

	regress incumbent_share treatment i.blid  if goodnews==1 & dosage==0&blid!=37, vce(cluster newid)
			outreg2 using "Tables/lowdosage_robustness.tex", tex(fra) keep(treatment) dec(2) label append ctitle("Kpomasse, Removed") nonotes

	regress incumbent_share treatment i.blid  if goodnews==1 & dosage==0&blid!=57, vce(cluster newid)
		outreg2 using "Tables/lowdosage_robustness.tex", tex(fra) keep(treatment) dec(2) label append ctitle("Za-Kpota, Removed") nonotes

*** Table G.3
	* main specification
	regress incumbent_share infoonly civics  i.blid  if goodnews==1 & dosage==1 , vce(cluster newid)
			outreg2 using "Tables/civics_robustness.tex", tex(fra) keep(infoonly civics) dec(2) label replace ctitle("Main, Specification") nonotes ///
			addnote("In parentheses, robust standard errors clustered by commune x treatment. Models include block fixed effects. *** p$<$0.01, ** p$<$0.05, * p$<$0.1.") 


	* no weights
	regress incumbent_share infoonly civics  i.blid [pw=ipw] if goodnews==1 & dosage==1 , vce(cluster newid)
			outreg2 using "Tables/civics_robustness.tex", tex(fra) keep(infoonly civics) dec(2) label append ctitle("Weights") nonotes
		
	* commune fixed effects
	regress incumbent_share infoonly civics  i.cid if goodnews==1 & dosage==1 , vce(cluster newid)
			outreg2 using "Tables/civics_robustness.tex", tex(fra) keep(infoonly civics) dec(2) label append ctitle("Commune, Fixed Effects") nonotes
	
	* no fixed effects
	regress incumbent_share infoonly civics  if goodnews==1 & dosage==1 , vce(cluster newid)
			outreg2 using "Tables/civics_robustness.tex",tex(fra) keep(infoonly civics) dec(2) label append ctitle("No, Fixed Effects") nonotes
	
	* remove one commune at a time
	regress incumbent_share infoonly civics  i.blid  if goodnews==1 & dosage==1&commune~="BANTE" , vce(cluster newid)
			outreg2 using "Tables/civics_robustness.tex", tex(fra) keep(infoonly civics) dec(2) label append ctitle("Bante, Removed") nonotes

	regress incumbent_share infoonly civics  i.blid if goodnews==1 & dosage==1&commune~="BEMBEREKE" , vce(cluster newid)
			outreg2 using "Tables/civics_robustness.tex", tex(fra) keep(infoonly civics) dec(2) label append ctitle("Bembereke, Removed") nonotes
		
	regress incumbent_share infoonly civics  i.blid  if goodnews==1 & dosage==1&commune~="BOPA" , vce(cluster newid)
			outreg2 using "Tables/civics_robustness.tex",tex(fra) keep(infoonly civics) dec(2) label append ctitle("Bopa, Removed") nonotes
			
	regress incumbent_share infoonly civics  i.blid  if goodnews==1 & dosage==1&commune~="COME" , vce(cluster newid)
			outreg2 using "Tables/civics_robustness.tex", tex(fra) keep(infoonly civics) dec(2) label append ctitle("Come, Removed") nonotes
			
	regress incumbent_share infoonly civics  i.blid  if goodnews==1 & dosage==1&commune~="KETOU" , vce(cluster newid)
			outreg2 using "Tables/civics_robustness.tex", tex(fra) keep(infoonly civics) dec(2) label append ctitle("Ketou, Removed") nonotes

	regress incumbent_share infoonly civics  i.blid  if goodnews==1 & dosage==1&commune~="KOUANDE" , vce(cluster newid)
			outreg2 using "Tables/civics_robustness.tex",tex(fra) keep(infoonly civics) dec(2) label append ctitle("Kouande, Removed") nonotes
			
	regress incumbent_share infoonly civics  i.blid  if goodnews==1 & dosage==1&commune~="SEGBANA" , vce(cluster newid)
			outreg2 using "Tables/civics_robustness.tex",tex(fra) keep(infoonly civics) dec(2) label append ctitle("Segbana, Removed") nonotes
		
	regress incumbent_share infoonly civics  i.blid  if goodnews==1 & dosage==1&commune~="TCHAOUROU" , vce(cluster newid)
			outreg2 using "Tables/civics_robustness.tex",tex(fra) keep(infoonly civics) dec(2) label append ctitle("Tchaourou, Removed") nonotes

	regress incumbent_share infoonly civics  i.blid  if goodnews==1 & dosage==1&commune~="ZE" , vce(cluster newid)
			outreg2 using "Tables/civics_robustness.tex",tex(fra) keep(infoonly civics) dec(2) label append ctitle("Ze, Removed") nonotes

*** Table G.4
label var quart "Quartile registered voters"
tab quart, gen(quart_)	
	label variable quart_1 "1st quartile"
	label variable quart_2 "2nd quartile"
	label variable quart_3 "3rd quartile"
	label variable quart_4 "4th quartile"

forvalues i = 1/4{
gen treatment_quart_`i'=treatment*quart_`i'
label var treatment_quart_`i' "Treatment x Quartile `i'"
gen private_quart_`i'=private*quart_`i'
label var private_quart_`i' "Private x Quartile `i'"
gen public_quart_`i'=public*quart_`i'
label var public_quart_`i' "Public x Quartile `i'"
gen civics_quart_`i'=civics*quart_`i'
label var civics_quart_`i' "Civics x Quartile `i'"
gen infoonly_quart_`i'=infoonly*quart_`i'
label var infoonly_quart_`i' "Info only x Quartile `i'"
}
	
areg incumbent_share treatment quart_* treatment_quart* if goodnews==1&dosage==0, absorb(blid) vce(cluster newid)
	outreg2 using "Tables/res1a_villagesize.tex", replace dec(3) ctitle("Low Dose") tex(fra) label sortvar(treatment quart_* treatment_*) drop(quart_4 treatment_quart_4) nonotes ///
		addnote("In parentheses, robust standard errors clustered by commune in model 1 and commune x treatment, otherwise." ,   "Models include block fixed effects. *** p$<$0.01, ** p$<$0.05, * p$<$0.1.") ///
	
areg incumbent_share treatment quart_* treatment_quart* if goodnews==1 & dosage==1&civics==0, vce(cluster newid) absorb(blid)
	outreg2 using "Tables/res1a_villagesize.tex", append dec(3) ctitle("High Dose", "No Civics") sortvar(treatment quart_* treatment_*) tex(fra) label drop(quart_4 treatment_quart_4) nonotes
	
*Remove ADJOZOUNME when comparing public to private since it got both
areg incumbent_share public private quart_* public_quart* private_quart*  if goodnews==1 & dosage==1&civics==0 & village!="ADJOZOUNME", vce(cluster newid) absorb(blid)
	outreg2 using "Tables/res1a_villagesize.tex", append dec(3) ctitle("High Dose", "No Civics") sortvar(treatment quart_* treatment_*) tex(fra) label drop(quart_4 public_quart_4 private_quart_4) nonotes
	
areg incumbent_share civics infoonly quart_* civics_quart* infoonly_quart*  if goodnews==1 & dosage==1, vce(cluster newid) absorb(blid)
	outreg2 using "Tables/res1a_villagesize.tex", append dec(3) ctitle("All High" , "Dose") sortvar(treatment quart_* treatment_*) tex(fra) label drop(quart_4 civics_quart_4 infoonly_quart_4) nonotes

	
	
*** Table G.5
areg incumbent_share treatment  if goodnews==1&dosage==0&survey_sample==1, absorb(blid) vce(cluster newid)
	outreg2 using "Tables/res1a_surveysample.tex", replace dec(3) ctitle("Low Dose") tex(fra) label sortvar(treatment private public infoonly civics dose_civics ) nonotes ///
		addnote("In parentheses, robust standard errors clustered by commune in model 1 and commune x treatment,"" , ""otherwise. Models include block fixed effects. *** p$<$0.01, ** p$<$0.05, * p$<$0.1.") ///

areg incumbent_share treatment   if goodnews==1 & dosage==1&civics==0&survey_sample==1, vce(cluster newid) absorb(blid)
	outreg2 using "Tables/res1a_surveysample.tex", append dec(3) ctitle("High Dose", "No Civics") sortvar(treatment private public infoonly civics dose_civics )  tex(fra) label nonotes

areg incumbent_share private public  if goodnews==1 & dosage==1&civics==0&survey_sample==1, vce(cluster newid) absorb(blid)
	outreg2 using "Tables/res1a_surveysample.tex", append dec(3) ctitle("High Dose", "No Civics") sortvar(treatment private public infoonly civics dose_civics )  tex(fra) label nonotes
	
areg incumbent_share infoonly civics   if goodnews==1 & dosage==1&survey_sample==1, vce(cluster newid) absorb(blid)
	outreg2 using "Tables/res1a_surveysample.tex", append dec(3) ctitle("All High" , "Dose") sortvar(treatment private public infoonly civics dose_civics )  tex(fra) label nonotes
	test infoonly=civics
	
areg incumbent_share infoonly civics dose_civics   if goodnews==1&survey_sample==1, absorb(blid) vce(cluster newid)
	outreg2 using "Tables/res1a_surveysample.tex", append dec(3) ctitle("All", "Communes") sortvar(treatment private public infoonly civics dose_civics )  tex(fra) label nonotes

	

*** Table G.6
label variable margin "Vote margin in previous election (continuous)"
label var information_source1 "Information from radio"
label var information_source2 "Information from newspaper"
label var information_source3 "Information from television"

*use controls specified in pre-analysis plan section 8.4 on covariate adjustment
local Xs female educyears coethnic age povertyA information_source1-information_source3 homogeneity secret_ballot know_village_vote

areg incumbent_share treatment  `Xs' if goodnews==1 & dosage==1&civics==0, vce(cluster newid) absorb(blid)
	outreg2 using "Tables/res1a_controls.tex", replace dec(3) ctitle("High Dose", "No Civics") sortvar(treatment private public infoonly civics dose_civics )  tex(fra) label nonotes ///
		addnote("In parentheses, robust standard errors clustered by commune x treatment." ,   "Models include block fixed effects. *** p$<$0.01, ** p$<$0.05, * p$<$0.1.") ///

areg incumbent_share private public `Xs'  if goodnews==1 & dosage==1&civics==0, vce(cluster newid) absorb(blid)
	outreg2 using "Tables/res1a_controls.tex", append dec(3) ctitle("High Dose", "No Civics") sortvar(treatment private public infoonly civics dose_civics )  tex(fra) label nonotes 
	

areg incumbent_share infoonly civics  `Xs' if goodnews==1 & dosage==1, vce(cluster newid) absorb(blid)
	outreg2 using "Tables/res1a_controls.tex", append dec(3) ctitle("All High" , "Dose") sortvar(treatment private public infoonly civics dose_civics )  tex(fra) label nonotes 
	test infoonly=civics
	
areg incumbent_share infoonly civics dose_civics  `Xs' if goodnews==1, absorb(blid) vce(cluster newid)
	outreg2 using "Tables/res1a_controls.tex", append dec(3) ctitle("All", "Communes") sortvar(treatment private public infoonly civics dose_civics )  tex(fra) label nonotes 

	
************************************************
*Appendix H: Deviations from Pre-Analysis Plan*
************************************************

***Table H.1
gen tr_dosage = treatment*dosage
	label variable tr_dosage "Treatment x Dosage"

tab condition, gen(cond)	
	label variable cond1 "Control"
	label variable cond2 "Private, Information Only"
	label variable cond3 "Public, Information Only"
	label variable cond4 "Private, Civics"
	label variable cond5 "Public, Civics"

areg incumbent_share cond5 [pw=ipw]    if goodnews==1&dosage==0, absorb(blid) vce(cluster newid)
	outreg2 using "Tables/res_app.tex", replace dec(3) ctitle("Good News" , "Low Dose") tex(fra) label ///
		sortvar(cond5 infoonly civics private public  treatment tr_dosage dosage) keep(cond5 infoonly civics private public  treatment tr_dosage dosage) nonotes ///

areg incumbent_share infoonly civics [pw=ipw]   if goodnews==1&dosage==1, absorb(blid) vce(cluster newid)
outreg2 using "Tables/res_app.tex", append dec(3) ctitle("Good News" , "High Dose") tex(fra) label ///
		sortvar(cond5 infoonly civics private public  treatment tr_dosage dosage) keep(cond5 infoonly civics private public  treatment tr_dosage dosage) nonotes		

areg incumbent_share private public [pw=ipw]   if goodnews==1&dosage==1, absorb(blid) vce(cluster newid)
outreg2 using "Tables/res_app.tex", append dec(3) ctitle("Good News" , "High Dose") tex(fra) label ///
		sortvar(cond5 infoonly civics private public  treatment tr_dosage dosage) keep(cond5 infoonly civics private public  treatment tr_dosage dosage) nonotes		
		
regress incumbent_share treatment tr_dosage dosage i.original_block [pw=ipw]   if goodnews==1,  vce(cluster newid)
outreg2 using "Tables/res_app.tex", append dec(3) ctitle("Good News" , "All Communes") tex(fra) label ///
		sortvar(cond5 infoonly civics private public  treatment tr_dosage dosage) keep(cond5 infoonly civics private public  treatment tr_dosage dosage) nonotes 


areg incumbent_share cond5 [pw=ipw]    if goodnews==0&dosage==0, absorb(blid) vce(cluster newid)
outreg2 using "Tables/res_app.tex", append dec(3) ctitle("Bad News" , "Low Dose") tex(fra) label ///
		sortvar(cond5 infoonly civics private public  treatment tr_dosage dosage) keep(cond5 infoonly civics private public  treatment tr_dosage dosage) nonotes 

areg incumbent_share infoonly civics[pw=ipw]   if goodnews==0&dosage==1, absorb(blid) vce(cluster newid)
outreg2 using "Tables/res_app.tex", append dec(3) ctitle("Bad News" , "High Dose") tex(fra) label ///
		sortvar(cond5 infoonly civics private public  treatment tr_dosage dosage) keep(cond5 infoonly civics private public  treatment tr_dosage dosage) nonotes 
		
areg incumbent_share private public [pw=ipw]   if goodnews==0&dosage==1, absorb(blid) vce(cluster newid)
outreg2 using "Tables/res_app.tex", append dec(3) ctitle("Bad News" , "High Dose") tex(fra) label ///
		sortvar(cond5 infoonly civics private public  treatment tr_dosage dosage) keep(cond5 infoonly civics private public  treatment tr_dosage dosage) nonotes 
				
regress incumbent_share treatment tr_dosage dosage i.original_block [pw=ipw]   if goodnews==0,  vce(cluster newid)
outreg2 using "Tables/res_app.tex", append dec(3) ctitle("Bad News" , "All Communes") tex(fra) label ///
		sortvar(cond5 infoonly civics private public  treatment tr_dosage dosage) keep(cond5 infoonly civics private public  treatment tr_dosage dosage) nonotes 

		
********************************************************
*Appendix I: Attrition and Response Bias in Survey Data*
********************************************************

*** Table I.1
use Data/temp/survey, clear

gen newid=cid*100 + condition_numeric

gen attrition=1 if nosurvey==0
	replace attrition=0 if (consent==1&nosurvey==0)
	label variable attrition "Attrition (consent to endline)"
	
gen attrition_vote = 1
		replace attrition_vote = 0 if endlineeq6==0 | endlineeq6==1
		replace attrition_vote = . if nosurvey==1
		label variable attrition_vote "Attrition (answered incumbent vote question)"

areg attrition public private, absorb(blid) vce(cluster newid)
	outreg2 using "Tables/attrition_final.tex", replace dec(3) ctitle("Endline") tex(fra) label nonotes ///
		addnote("In parentheses, robust standard errors clustered by commune x treatment condition." ,   "Models include block fixed effects. *** p$<$0.01, ** p$<$0.05, * p$<$0.1.") ///
	
areg attrition_vote public private, absorb(blid) vce(cluster newid)
	outreg2 using "Tables/attrition_final.tex", append dec(3) ctitle("Vote choice") tex(fra) label nonotes ///

areg attrition civics infoonly, absorb(blid) vce(cluster newid)
	outreg2 using "Tables/attrition_final.tex", append dec(3) ctitle("Endline") tex(fra) label nonotes ///

areg attrition_vote civics infoonly, absorb(blid) vce(cluster newid)
	outreg2 using "Tables/attrition_final.tex", append dec(3) ctitle("Vote choice") tex(fra) label nonotes
	

*** Table I.2
generate treatment_female=treatment*female
label var treatment_female "Treatment x Female"
	
generate treatment_coethnic=treatment*coethnic
label var treatment_coethnic "Treatment x Coethnicity"

generate treatment_prior=treatment*overall_prior
label var treatment_prior "Treatment x Positive Prior"

areg attrition treatment female coethnic overall_prior educyears urban margin, absorb(blid) vce(cluster newid)
	outreg2 using "Tables/attrition_predictors_final.tex", replace dec(3) ctitle("Endline") tex(fra) label nonotes ///
		addnote("In parentheses, robust standard errors clustered by commune x treatment condition." ,   "Models include block fixed effects. *** p$<$0.01, ** p$<$0.05, * p$<$0.1.") ///

areg attrition_vote treatment female coethnic overall_prior educyears urban margin, absorb(blid) vce(cluster newid)
	outreg2 using "Tables/attrition_predictors_final.tex", append dec(3) ctitle("Vote choice") tex(fra) label nonotes

areg attrition treatment female treatment_female, absorb(blid) vce(cluster newid)
	outreg2 using "Tables/attrition_predictors_final.tex", append dec(3) ctitle("Endline") tex(fra) label nonotes ///
	
areg attrition_vote treatment female treatment_female, absorb(blid) vce(cluster newid)
	outreg2 using "Tables/attrition_predictors_final.tex", append dec(3) ctitle("Vote choice") tex(fra) label nonotes ///

areg attrition treatment coethnic treatment_coethnic, absorb(blid) vce(cluster newid)
	outreg2 using "Tables/attrition_predictors_final.tex", append dec(3) ctitle("Endline") tex(fra) label nonotes ///

areg attrition_vote treatment coethnic treatment_coethnic, absorb(blid) vce(cluster newid)
	outreg2 using "Tables/attrition_predictors_final.tex", append dec(3) ctitle("Vote choice") tex(fra) label nonotes



*** Table I.3
use "Data/merged_administrative", clear

keep if merge2015==3

generate turnout_official=(total_valid+total_annulees)/regvoters
label var turnout_official "Official voter turnout"
replace turnout_official=. if turnout>1

gen deviation1 = turnout-turnout_official

gen vtreated_goodnews=treatment*goodnews

label var treatment "Treatment"
label var goodnews "Good News"
label var vtreated_goodnews "Treatment x Good News"



regress deviation1 treatment 
	outreg2 using "Tables/deviation1.tex", replace dec(3) tex(fra) label ctitle(" ") ///

regress deviation1 treatment goodnews vtreated_goodnews 
	outreg2 using "Tables/deviation1.tex", append dec(3) tex(fra) label ctitle(" ")

*** Table I.4
** incumbent_vote is the mean from the survey data
** incumbent_share is the actual voteshare as calculated from the official resutlts

** calculate the deviationon between reported voteshare and actual voteshare

gen deviation = incumbent_vote-incumbent_share

regress deviation treatment
	outreg2 using "Tables/deviation2.tex", replace dec(3) tex(fra) label ctitle(" ") ///

regress deviation treatment goodnews vtreated_goodnews 
	outreg2 using "Tables/deviation2.tex", append dec(3) tex(fra) label ctitle(" ")


***Table I.5
use Data/temp/official, clear

gen dev = sum_incumbent - votes_incumbent

sort treatment goodnews
list village commune treatment goodnews sum_incumbent votes_incumbent dev if dev > 0 & dev~=.

gen tr = "Yes" if treatment==1
	replace tr = "No" if treatment==0

gen gn = "Yes" if goodnews==1
	replace gn = "No" if goodnews==0

listtex village  tr gn sum_incumbent votes_incumbent   using "Tables/over_reporting.tex" ///
	if dev > 0 & dev~=., replace ///
	rstyle(tabular) head("\begin{tabular}{lcccc} "" \textit{Village} &\textit{Treatment}&\textit{Good News} &\textit{Reported Votes (survey)} &\textit{Official Votes}   \\ \hline \\") ///
	 foot("\end{tabular}") end("\\ \hline \\")

***********************************************************
*Appendix J: Replication of Main Results Using Survey Data*
***********************************************************

use Data/temp/survey, clear

*** Table J.1
gen dose_civics = dosage*civics

areg incumbent_v treatment   if goodnewsrelative2==1&dosage==0, absorb(blid) vce(cluster quartier)
	outreg2 using "Tables/res1a_survey.tex", replace dec(3) ctitle("Low Dose") tex(fra) label sortvar(treatment) nonotes ///
		addnote("In parentheses, robust standard errors clustered by village." ,   "Models include block fixed effects. *** p$<$0.01, ** p$<$0.05, * p$<$0.1.") ///
	
areg incumbent_v treatment  if goodnewsrelative2==1 & dosage==1&civics==0, vce(cluster quartier) absorb(blid)
	outreg2 using "Tables/res1a_survey.tex", append dec(3) ctitle("High Dose", "No Civics") sortvar(treatment) tex(fra) label nonotes

areg incumbent_v private public  if goodnewsrelative2==1 & dosage==1&civics==0, vce(cluster quartier) absorb(blid)
	outreg2 using "Tables/res1a_survey.tex", append dec(3) ctitle("High Dose", "No Civics") sortvar(treatment) tex(fra) label nonotes

areg incumbent_v private public  if goodnewsrelative2==1 & dosage==1, vce(cluster quartier) absorb(blid)
	outreg2 using "Tables/res1a_survey.tex", append dec(3) ctitle("All High" , "Dose") sortvar(treatment) tex(fra) label nonotes
	
	
areg incumbent_v infoonly civics  if goodnewsrelative2==1 & dosage==1, vce(cluster quartier) absorb(blid)
	outreg2 using "Tables/res1a_survey.tex", append dec(3) ctitle("All High" , "Dose") sortvar(treatment) tex(fra) label nonotes
	test infoonly=civics
	
areg incumbent_v infoonly civics dose_civics  if goodnewsrelative2==1, absorb(blid) vce(cluster quartier)
	outreg2 using "Tables/res1a_survey.tex", append dec(3) ctitle("All", "Communes") sortvar(treatment) tex(fra) label nonotes
	
*** Table J.2
local Xs  female coethnic 

areg incumbent_v treatment `Xs'  if goodnewsrelative2==1&dosage==0, absorb(blid) vce(cluster quartier)
	outreg2 using "Tables/res1a_survey_controls.tex", replace dec(3) ctitle("Low Dose") tex(fra) label sortvar(treatment) nonotes ///
		addnote("In parentheses, robust standard errors clustered by village." ,   "Models include block fixed effects. *** p$<$0.01, ** p$<$0.05, * p$<$0.1.") ///
	
areg incumbent_v treatment `Xs' if goodnewsrelative2==1 & dosage==1&civics==0, vce(cluster quartier) absorb(blid)
	outreg2 using "Tables/res1a_survey_controls.tex", append dec(3) ctitle("High Dose", "No Civics") sortvar(treatment) tex(fra) label nonotes

areg incumbent_v private public `Xs'  if goodnewsrelative2==1 & dosage==1&civics==0, vce(cluster quartier) absorb(blid)
	outreg2 using "Tables/res1a_survey_controls.tex", append dec(3) ctitle("High Dose", "No Civics") sortvar(treatment) tex(fra) label nonotes

areg incumbent_v private public  `Xs' if goodnewsrelative2==1 & dosage==1, vce(cluster quartier) absorb(blid)
	outreg2 using "Tables/res1a_survey_controls.tex", append dec(3) ctitle("All High" , "Dose") sortvar(treatment) tex(fra) label nonotes
	
	
areg incumbent_v infoonly civics `Xs' if goodnewsrelative2==1 & dosage==1, vce(cluster quartier) absorb(blid)
	outreg2 using "Tables/res1a_survey_controls.tex", append dec(3) ctitle("All High" , "Dose") sortvar(treatment) tex(fra) label nonotes
	test infoonly=civics
	
areg incumbent_v infoonly civics dose_civics `Xs'  if goodnewsrelative2==1, absorb(blid) vce(cluster quartier)
	outreg2 using "Tables/res1a_survey_controls.tex", append dec(3) ctitle("All", "Communes") sortvar(treatment) tex(fra) label nonotes
	
*** Table J.3
areg incumbent_v treatment   if goodnewsrelative2==0&dosage==0, absorb(blid) vce(cluster quartier)
	outreg2 using "Tables/res1b_survey.tex", replace dec(3) ctitle("Low Dose") tex(fra) label sortvar(treatment) nonotes ///
		addnote("In parentheses, robust standard errors clustered by village." ,   "Models include block fixed effects. *** p$<$0.01, ** p$<$0.05, * p$<$0.1.") ///
	
areg incumbent_v treatment  if goodnewsrelative2==0 & dosage==1&civics==0, vce(cluster quartier) absorb(blid)
	outreg2 using "Tables/res1b_survey.tex", append dec(3) ctitle("High Dose", "No Civics") sortvar(treatment) tex(fra) label nonotes

areg incumbent_v private public  if goodnewsrelative2==0 & dosage==1&civics==0, vce(cluster quartier) absorb(blid)
	outreg2 using "Tables/res1b_survey.tex", append dec(3) ctitle("High Dose", "No Civics") sortvar(treatment) tex(fra) label nonotes

areg incumbent_v private public  if goodnewsrelative2==0 & dosage==1, vce(cluster quartier) absorb(blid)
	outreg2 using "Tables/res1b_survey.tex", append dec(3) ctitle("All High" , "Dose") sortvar(treatment) tex(fra) label nonotes
	
areg incumbent_v infoonly civics  if goodnewsrelative2==0 & dosage==1, vce(cluster quartier) absorb(blid)
	outreg2 using "Tables/res1b_survey.tex", append dec(3) ctitle("All High" , "Dose") sortvar(treatment) tex(fra) label nonotes
	test infoonly=civics
	
areg incumbent_v infoonly civics dose_civics  if goodnewsrelative2==0, absorb(blid) vce(cluster quartier)
	outreg2 using "Tables/res1b_survey.tex", append dec(3) ctitle("All", "Communes") sortvar(treatment) tex(fra) label nonotes

***********************************************************
*Appendix K: Analysis of Continuous Measure of Performance*
***********************************************************

use Data/temp/official, clear

*** Table K.1

gen tr_main = treatment*main_index
	label variable tr_main "Treatment x Overall Index (continuous)"
gen private_main = private*main_index
	label variable private_main "Private x Overall Index (continuous)"
gen public_main = public*main_index
	label variable public_main "Public x Overall Index (continuous)"
gen info_main = infoonly*main_index
	label variable info_main "Info Only x Overall Index (continuous)"
gen civics_main = civics*main_index
	label variable civics_main "Civics x Overall Index (continuous)"
	
gen triple = civics*dosage*main_index	
	label variable triple "Civics x Dosage x Overall Index"


areg incumbent_share treatment tr_main if dosage==0   , absorb(blid) vce(cluster newid)
outreg2 using "Tables/res1a_continuous.tex", replace dec(3) ctitle("Low Dose") tex(fra) label sortvar(treatment tr_main) nonotes ///
		addnote("In parentheses, robust standard errors clustered by commune in model 1 and commune x treatment,"" , ""otherwise. Models include block fixed effects. *** p$<$0.01, ** p$<$0.05, * p$<$0.1.") ///

areg incumbent_share treatment tr_main if  dosage==1&civics==0, vce(cluster newid) absorb(blid)
	outreg2 using "Tables/res1a_continuous.tex", append dec(3) ctitle("High Dose", "No Civics") sortvar(treatment) tex(fra) label nonotes

areg incumbent_share private private_main public public_main  if  dosage==1&civics==0, vce(cluster newid) absorb(blid)
	outreg2 using "Tables/res1a_continuous.tex", append dec(3) ctitle("High Dose", "No Civics") sortvar(treatment) tex(fra) label nonotes
	
	
areg incumbent_share infoonly info_main civics civics_main  if dosage==1, vce(cluster newid) absorb(blid)
	outreg2 using "Tables/res1a_continuous.tex", append dec(3) ctitle("All High" , "Dose") sortvar(treatment) tex(fra) label nonotes
		
areg incumbent_share infoonly civics dose_civics civics_main triple  , absorb(blid) vce(cluster newid)
	outreg2 using "Tables/res1a_continuous.tex", append dec(3) ctitle("All", "Communes") sortvar(treatment) tex(fra) label nonotes

***********************************************************
**************Appendix L: Spillovers***********************
***********************************************************

*** Table L.1
generate dosage_treatment=dosage * treatment
label var dosage_treatment "Dosage x Treatment"

reg incumbent_share dosage if treatment==0 & blid!=., vce(cluster commune)
	outreg2 using "Tables/spillovers1.tex", replace dec(3) tex(fra) label ctitle("Whole Sample") nonotes ///
	addnote("In parentheses, robust standard errors clustered by commune." ,   "Models include block fixed effects. *** p$<$0.01, ** p$<$0.05, * p$<$0.1.") ///

reg incumbent_share dosage if treatment==0 & goodnews==1 & blid!=., vce(cluster commune)
	outreg2 using "Tables/spillovers1.tex", append dec(3) tex(fra) label ctitle("Positive Info") nonotes

reg incumbent_share dosage if treatment==0 & goodnews==0 & blid!=., vce(cluster commune)
	outreg2 using "Tables/spillovers1.tex", append dec(3) tex(fra) label ctitle("Negative Info") nonotes

xtmixed incumbent_share dosage treatment dosage_treatment if goodnews==1 || blid:, vce(cluster commune)
	outreg2 using "Tables/spillovers1.tex", append dec(3) drop(lnsig_e: lns1_1_1:) eqkeep(none) noni tex(fra) label ctitle("Positive Info") nonotes

mixed incumbent_share dosage treatment dosage_treatment if goodnews==0 || blid:, vce(cluster commune)
	outreg2 using "Tables/spillovers1.tex", append dec(3) noni  drop(lnsig_e: lns1_1_1:) eqkeep(none) tex(fra) label ctitle("Negative Info") nonotes
	
*** Table L.2
use Data/temp/survey, clear

generate knowperf=abs(overall_departement - endlineeq16) if endlineeq16<5

reg knowperf dosage if treatment==0, vce(cluster quartier)
	outreg2 using "Tables/spillovers2", replace dec(3) ctitle("Whole Sample") tex(fra) label  ///
		addnote("In parentheses, robust standard errors clustered by village." ,   "*** p$<$0.01, ** p$<$0.05, * p$<$0.1.") ///

reg knowperf dosage if treatment==0 & goodnews==1, vce(cluster quartier)
	outreg2 using "Tables/spillovers2", append dec(3) ctitle("Positive Info") tex(fra) label  

reg knowperf dosage if treatment==0 & goodnews==0, vce(cluster quartier)
	outreg2 using "Tables/spillovers2", append dec(3) ctitle("Negative Info") tex(fra) label
	
*** Table L.3
gen info_private = 0 if typet3~=. &typet3~=3
replace info_private = 1 if typet3==1 & infoonly==1	

gen civics_private = 0 if typet3~=. &typet3~=3
replace civics_private = 1 if typet3==1 & civics==1	

gen pr_ipw = 1/(1/3) if controlinprivate==1
replace pr_ipw = 1/(2/3) if controlinprivate==0 & private==1

logit incumbent_vote info_priv  [pweight=pr_ipw] if infoonly==1 & private==1 &goodnewsrelative2==1,  vce(cluster quartier)
est store InfoOnlyVillages
logit incumbent_vote civics_private  [pweight=pr_ipw] if civics==1 & private==1 &goodnewsrelative2==1,  vce(cluster quartier)
est store CivicsVillages
logit incumbent_vote info_priv civics_private  [pweight=pr_ipw] if private==1 &goodnewsrelative2==1,  vce(cluster quartier)
est store AllPrivateVillages

esttab InfoOnlyVillages CivicsVillages AllPrivateVillages using "Tables/spilloverscommonarm.tex", ///
star(* 0.10 ** 0.05 *** 0.01) se b(3) se(3) r2(2) replace  ///
stats(N, layout("\multicolumn{1}{c}{@}") fmt(%8.0g)) ///
title(Effect of positive performance information, comparing treatment and control within private villages (logit) \label{tab:spilloverscommonarm})  ///
varlabels (info_private "Info-Only" civics_private "Info-Only + Civics" _cons Constant) ///
nobaselevels nodepvars nogaps nonotes nonum ///
addnote("Robust standard errors in parentheses clustered by village. Inverse probability weights." "$^* p<0.10$, $^{**} p<0.05$, $^{***} p<0.01$" "Dependent variable is binary (1=voted for incumbent, 0=voted for another or did not vote)." "Good news defined using survey data.")
eststo clear

*** Table L.4
logit incumbent_vote info_priv  [pweight=pr_ipw] if infoonly==1 & private==1 &goodnewsrelative2==0,  vce(cluster quartier)
est store InfoOnlyVillages
logit incumbent_vote civics_private  [pweight=pr_ipw] if civics==1 & private==1 &goodnewsrelative2==0,  vce(cluster quartier)
est store CivicsVillages
logit incumbent_vote info_priv civics_private  [pweight=pr_ipw] if private==1 &goodnewsrelative2==0,  vce(cluster quartier)
est store AllPrivateVillages

esttab InfoOnlyVillages CivicsVillages AllPrivateVillages using "Tables/spilloverscommonarmbad.tex", ///
star(* 0.10 ** 0.05 *** 0.01) se b(3) se(3) r2(2) replace  ///
stats(N, layout("\multicolumn{1}{c}{@}") fmt(%8.0g)) ///
title(Effect of negative performance information, comparing treatment and control within private villages (logit) \label{tab:spilloverscommonarmbad})  ///
varlabels (info_private "Info-Only" civics_private "Info-Only + Civics" _cons Constant) ///
nobaselevels nodepvars nogaps nonotes nonum ///
addnote("Robust standard errors in parentheses clustered by village. Inverse probability weights." "$^* p<0.10$, $^{**} p<0.05$, $^{***} p<0.01$" "Dependent variable is binary (1=voted for incumbent, 0=voted for another or did not vote)." "Good news defined using survey data." )
eststo clear

***********************************************************
*********Appendix M: Impacts on Turnout *******************
***********************************************************

use Data/temp/official, clear

*Drop those that were not matching
keep if merge2015==3


*** Table M.1
local order treatment infoonly civics public private t1t3 t1t4 t2t3 t2t4 dose_civics

areg turnout treatment   if goodnews==1, absorb(blid) vce(cluster newid)
outreg2 using "Tables/res1a_turnout_2.tex", replace dec(2) ctitle("All" , "Communes") tex(fra) label sortvar(`order') nonotes ///
		addnote("In parentheses, robust standard errors clustered by commune in model 1 and commune x treatment,"" , ""otherwise. Models include block fixed effects. *** p$<$0.01, ** p$<$0.05, * p$<$0.1.") 
	
areg turnout treatment   if goodnews==1&dosage==0, absorb(blid) vce(cluster newid)
		outreg2 using "Tables/res1a_turnout_2.tex", append dec(2) ctitle("Low", "Dosage") sortvar(`order') tex(fra) label nonotes

areg turnout treatment   if goodnews==1&dosage==1, absorb(blid) vce(cluster newid)
		outreg2 using "Tables/res1a_turnout_2.tex", append dec(2) ctitle("High", "Dosage") sortvar(`order') tex(fra) label nonotes
	
areg turnout infoonly civics   if goodnews==1&dosage==1, absorb(blid) vce(cluster newid)
		outreg2 using "Tables/res1a_turnout_2.tex", append dec(2) ctitle("High", "Dosage") sortvar(`order') tex(fra) label nonotes
	
areg turnout private public   if goodnews==1&dosage==1& village!="ADJOZOUNME", absorb(blid) vce(cluster newid)
		outreg2 using "Tables/res1a_turnout_2.tex", append dec(2) ctitle("High", "Dosage") sortvar(`order') tex(fra) label nonotes

areg turnout infoonly civics dose_civics  if goodnews==1, absorb(blid) vce(cluster newid)
	outreg2 using "Tables/res1a_turnout_2.tex", append dec(2) ctitle("All", "Communes") sortvar(`order') tex(fra) label nonotes

*** Table M.2
local order treatment infoonly civics public private t1t3 t1t4 t2t3 t2t4 dose_civics

areg turnout treatment   if goodnews==0, absorb(blid) vce(cluster newid)
outreg2 using "Tables/res2a_turnout_2.tex", replace dec(2) ctitle("All" , "Communes") tex(fra) label sortvar(`order') nonotes ///
		addnote("In parentheses, robust standard errors clustered by commune in model 1 and commune x treatment,"" , ""otherwise. Models include block fixed effects. *** p$<$0.01, ** p$<$0.05, * p$<$0.1.") 
	
areg turnout treatment   if goodnews==0&dosage==0, absorb(blid) vce(cluster newid)
		outreg2 using "Tables/res2a_turnout_2.tex", append dec(2) ctitle("Low", "Dosage") sortvar(`order') tex(fra) label nonotes

areg turnout treatment   if goodnews==0&dosage==1, absorb(blid) vce(cluster newid)
		outreg2 using "Tables/res2a_turnout_2.tex", append dec(2) ctitle("High", "Dosage") sortvar(`order') tex(fra) label nonotes
	
areg turnout infoonly civics   if goodnews==0&dosage==1, absorb(blid) vce(cluster newid)
		outreg2 using "Tables/res2a_turnout_2.tex", append dec(2) ctitle("High", "Dosage") sortvar(`order') tex(fra) label nonotes
	
areg turnout private public   if goodnews==0&dosage==1& village!="ADJOZOUNME", absorb(blid) vce(cluster newid)
		outreg2 using "Tables/res2a_turnout_2.tex", append dec(2) ctitle("High", "Dosage") sortvar(`order') tex(fra) label nonotes

areg turnout infoonly civics dose_civics  if goodnews==0, absorb(blid) vce(cluster newid)
	outreg2 using "Tables/res2a_turnout_2.tex", append dec(2) ctitle("All", "Communes") sortvar(`order') tex(fra) label nonotes
	
***********************************************************
*********Appendix N: Candidate Vignette*******************
***********************************************************
use Data/temp/survey, clear

***Figure N.1: see AGKM_Figures_SalienceandCoordination

***Figure N.2
replace endlineeq9_cservice = . if endlineeq9_cservice > 7
replace endlineeq9_control = . if endlineeq9_control > 7
replace endlineeq9_legislative = . if endlineeq9_legislative > 7

generate civics1=civics
replace civics1=2 if civics==1
replace civics1=1 if infoonly==1

label define civics1 0 "Control" 1 "Info Only" 2 "Salience Treatment"
label values civics1 civics1

label define goodnewsrelative2 0 "Bad News (relative)" 1 "Good News (relative)"
label values goodnewsrelative2 goodnewsrelative2
preserve
collapse (mean) endlineeq9_control endlineeq9_cservice endlineeq9_legislative if goodnewsrelative2==1, by(quartier blid civics1)
collapse (mean) endlineeq9_control endlineeq9_cservice endlineeq9_legislative (sd) sdcontrol=endlineeq9_control sdcservice=endlineeq9_cservice sdleg=endlineeq9_legislative (count) ncontrol=endlineeq9_control ncservice=endlineeq9_cservice nleg=endlineeq9_legislative, by(civics1)
generate hicontrol = endlineeq9_control + invttail(ncontrol-1,0.05)*(sdcontrol/sqrt(2*ncontrol))
generate lowcontrol = endlineeq9_control - invttail(ncontrol-1,0.05)*(sdcontrol/sqrt(2*ncontrol))
generate hicservice = endlineeq9_cservice + invttail(ncservice-1,0.05)*(sdcservice/sqrt(2*ncservice))
generate lowcservice = endlineeq9_cservice - invttail(ncservice-1,0.05)*(sdcservice/sqrt(2*ncservice))
generate hileg = endlineeq9_legislative + invttail(nleg-1,0.05)*(sdleg/sqrt(2*nleg))
generate lowleg = endlineeq9_legislative - invttail(nleg-1,0.05)*(sdleg/sqrt(2*nleg))
gen civics2=civics1-.2
gen civics3=civics1+.2
twoway bar endlineeq9_control civics2 , barw(0.18) ///
|| bar endlineeq9_cservice civics1, barw(0.18) ///
|| bar endlineeq9_legislative civics3, barw(0.18) ///
|| rcap hicontrol lowcontrol civics2 ///
|| rcap hicservice lowcservice civics1 ///
|| rcap hileg lowleg civics3, ///
xlabel(0 "Control" 1 "Info Only" 2 "Salience Treatment", noticks) ///
legend(order(1 "Control" 2 "Transfers" 3 "Legislative" 5 "5% Statistical Significance")col(3) pos(6)) ///
xtitle("Treatment Group") ytitle("Likelihood of voting for hypothetical candidate") ///
scheme(s2mono) graphregion(fcolor(white)) scale(.9) 
graph export "Figures/endlinevignette.pdf", replace
restore
